import { H as HighlighterGeneric, i as HighlighterCoreOptions, j as BundledHighlighterOptions, L as LanguageInput, g as ThemeInput, R as RequireKeys, C as CodeToHtmlOptions, b as CodeToHtmlThemesOptions, c as CodeToThemedTokensOptions, T as ThemedToken, d as CodeToTokensWithThemesOptions } from './types/langs.mjs';
export { A as Awaitable, B as BuiltinLanguages, a as BuiltinThemes, m as CodeToHtmlBasicOptions, E as ElementsOptions, q as HtmlRendererOptions, k as LanguageRegistration, n as LineOption, f as MaybeArray, M as MaybeGetter, e as MaybeModule, P as PlainTextLanguage, h as ResolveBundleKey, S as StringLiteralUnion, p as ThemeRegisteration, o as ThemeRegisterationRaw, s as ThemedTokenExplanation, r as ThemedTokenScopeExplanation, l as loadWasm } from './types/langs.mjs';

type HighlighterCore = HighlighterGeneric<never, never>;
declare function getHighlighterCore(options?: HighlighterCoreOptions): Promise<HighlighterCore>;

type GetHighlighterFactory<L extends string, T extends string> = (options?: BundledHighlighterOptions<L, T>) => Promise<HighlighterGeneric<L, T>>;
/**
 * Create a `getHighlighter` function with bundled themes and languages.
 *
 * @param bundledLanguages
 * @param bundledThemes
 * @param ladWasm
 */
declare function createdBundledHighlighter<BundledLangs extends string, BundledThemes extends string>(bundledLanguages: Record<BundledLangs, LanguageInput>, bundledThemes: Record<BundledThemes, ThemeInput>, ladWasm: HighlighterCoreOptions['loadWasm']): GetHighlighterFactory<BundledLangs, BundledThemes>;
declare function createSingletonShorthands<L extends string, T extends string>(getHighlighter: GetHighlighterFactory<L, T>): {
    codeToHtml: (code: string, options: RequireKeys<CodeToHtmlOptions<L, T>, 'theme' | 'lang'>) => Promise<string>;
    codeToHtmlThemes: (code: string, options: RequireKeys<CodeToHtmlThemesOptions<L, T>, 'themes' | 'lang'>) => Promise<string>;
    codeToThemedTokens: (code: string, options: RequireKeys<CodeToThemedTokensOptions<L, T>, 'theme' | 'lang'>) => Promise<ThemedToken[][]>;
    codeToTokensWithThemes: (code: string, options: RequireKeys<CodeToTokensWithThemesOptions<L, T>, 'themes' | 'lang'>) => Promise<[color: string, theme: string, tokens: ThemedToken[][]][]>;
};

export { BundledHighlighterOptions, CodeToHtmlOptions, CodeToHtmlThemesOptions, CodeToThemedTokensOptions, CodeToTokensWithThemesOptions, GetHighlighterFactory, HighlighterCore, HighlighterCoreOptions, HighlighterGeneric, LanguageInput, RequireKeys, ThemeInput, ThemedToken, createSingletonShorthands, createdBundledHighlighter, getHighlighterCore };
